# tty_ov

 A tiny terminal (just the functions I need) cross-platform implemented in python.

## Description

    This is an inner lib intended for a project, more details and a better structured readme will be implemented later on.
